@@ -5,12 +5,13 @@ plot.QA = function(x, ..., outDir = NULL){
   if(class(a[[1]])[1] != "QA"){
     stop("x must be one or more QA objects")
   }
+  
   if(!is.null(outDir)){
     if(class(outDir)[1] != "character"){
       stop("outDir should be a character string")
     }
     if(!dir.exists(outDir)){
-      warning("outDir does not exist, creating")
+      message("outDir does not exist, creating")
       dir.create(outDir)
     }
   }
